@@ -4,10 +4,15 @@ from load_confounds.strategies import (
     Params2,
     Params6,
     Params9,
+    Params9Scrub,
     Params24,
     Params36,
+    Params36Scrub,
     AnatCompCor,
     TempCompCor,
+    ICAAROMA,
+    AROMAGSR,
+    AggrICAAROMA,
 )
 
 __all__ = [
@@ -15,8 +20,13 @@ __all__ = [
     "Params2",
     "Params6",
     "Params9",
+    "Params9Scrub",
     "Params24",
     "Params36",
+    "Params36Scrub",
     "AnatCompCor",
     "TempCompCor",
+    "ICAAROMA",
+    "AROMAGSR",
+    "AggrICAAROMA",
 ]
